fs: remove 8 bytes of padding from struct writeback_control on 64 bit builds
Subsystems (2)
PATCH 1/1 fs: remove 8 bytes of padding from struct writeback_control on 64 bit builds
Reorder structure writeback_control to remove 8 bytes of padding on 64 bit builds, this shrinks its size from 48 to 40 bytes.
This structure is always on the stack and uses C99 named initialisation, so should be safe and have a small impact on stack usage.
--
patch against v3.4-rc4
compiled and tested on x86_64
I've been running my desktop with this patch applied for several days and have not seen any problems.
regards
Richard
include/linux/writeback.h +2 -1
@@ -58,7 +58,6 @@ extern const char *wb_reason_name[];* in a manner such that unspecified fields are set to zero. */ struct writeback_control { -enum writeback_sync_modes sync_mode;long nr_to_write;/* Write this many pages, and decrement this for each page written */ long pages_skipped;/* Pages which were not written */
@@ -71,6 +70,8 @@ struct writeback_control {loff_t range_start;loff_t range_end; +enum writeback_sync_modes sync_mode; + unsigned for_kupdate:1; /* A kupdate writeback */ unsigned for_background:1; /* A background writeback */ unsigned tagged_writepages:1; /* tag-and-write to avoid livelock */
Fengguang Wu
AppliedQuoted 10 lines · Richard Kennedy
Reorder structure
writeback_controlto remove 8 bytes of padding on 64 bit builds, this shrinks its size from 48 to 40 bytes.This structure is always on the stack and uses C99 named initialisation, so should be safe and have a small impact on stack usage.
Signed-off-by Richard Kennedy <[email protected]>--
Quoted 7 lines
patch against v3.4-rc4
compiled and tested onx86_64I've been running my desktop with this patch applied for several days and have not seen any problems.
regards
Richard
Applied, thanks!
Fengguang